@@ -87,6 +87,7 @@ enum {
 	PAT_MATCH_DOM,   /* domain-like sub-string (str) */
 	PAT_MATCH_END,   /* end of string (str) */
 	PAT_MATCH_REG,   /* regex (str -> reg) */
+	PAT_MATCH_REGM,  /* regex (str -> reg) with match zones */
 	/* keep this one last */
 	PAT_MATCH_NUM
 };
@@ -113,7 +114,6 @@ struct pat_ref {
  */
 struct pat_ref_elt {
 	struct list list; /* Used to chain elements. */
-	struct list back_refs; /* list of users tracking this pat ref */
 	char *pattern;
 	char *sample;
 	int line;
