@@ -105,7 +105,6 @@ struct acl_keyword *find_acl_kw(const char *kw)
 static struct acl_expr *prune_acl_expr(struct acl_expr *expr)
 {
 	struct arg *arg;
-	int unresolved = 0;
 
 	pattern_prune(&expr->pat);
 
@@ -115,13 +114,11 @@ static struct acl_expr *prune_acl_expr(struct acl_expr *expr)
 		if (arg->type == ARGT_STR || arg->unresolved) {
 			free(arg->data.str.str);
 			arg->data.str.str = NULL;
-			arg->data.str.len = 0;
-			unresolved |= arg->unresolved;
 			arg->unresolved = 0;
 		}
 	}
 
-	if (expr->smp->arg_p != empty_arg_list && !unresolved)
+	if (expr->smp->arg_p != empty_arg_list)
 		free(expr->smp->arg_p);
 	return expr;
 }
@@ -140,7 +137,7 @@ struct acl_expr *parse_acl_expr(const char **args, char **err, struct arg_list *
 	__label__ out_return, out_free_expr;
 	struct acl_expr *expr;
 	struct acl_keyword *aclkw;
-	int refflags, patflags;
+	int patflags;
 	const char *arg;
 	struct sample_expr *smp = NULL;
 	int idx = 0;
@@ -179,7 +176,7 @@ struct acl_expr *parse_acl_expr(const char **args, char **err, struct arg_list *
 		/* OK we have a real ACL keyword */
 
 		/* build new sample expression for this ACL */
-		smp = calloc(1, sizeof(struct sample_expr));
+		smp = calloc(1, sizeof(*smp));
 		if (!smp) {
 			memprintf(err, "out of memory when parsing ACL expression");
 			goto out_return;
@@ -245,7 +242,7 @@ struct acl_expr *parse_acl_expr(const char **args, char **err, struct arg_list *
 
 			if (*arg && *arg != ',') {
 				if (ckw)
-					memprintf(err, "ACL keyword '%s' : missing comma after conv keyword '%s'.",
+					memprintf(err, "ACL keyword '%s' : missing comma after converter '%s'.",
 						  aclkw->kw, ckw);
 				else
 					memprintf(err, "ACL keyword '%s' : missing comma after fetch keyword.",
@@ -256,7 +253,7 @@ struct acl_expr *parse_acl_expr(const char **args, char **err, struct arg_list *
 			while (*arg == ',') /* then trailing commas */
 				arg++;
 
-			begw = arg; /* start of conv keyword */
+			begw = arg; /* start of converter keyword */
 
 			if (!*begw)
 				/* none ? end of converters */
@@ -270,7 +267,7 @@ struct acl_expr *parse_acl_expr(const char **args, char **err, struct arg_list *
 			conv = find_sample_conv(begw, endw - begw);
 			if (!conv) {
 				/* Unknown converter method */
-				memprintf(err, "ACL keyword '%s' : unknown conv method '%s'.",
+				memprintf(err, "ACL keyword '%s' : unknown converter '%s'.",
 					  aclkw->kw, ckw);
 				goto out_free_smp;
 			}
@@ -281,27 +278,27 @@ struct acl_expr *parse_acl_expr(const char **args, char **err, struct arg_list *
 				while (*arg && *arg != ')')
 					arg++;
 				if (*arg != ')') {
-					memprintf(err, "ACL keyword '%s' : syntax error: missing ')' after conv keyword '%s'.",
+					memprintf(err, "ACL keyword '%s' : syntax error: missing ')' after converter '%s'.",
 						  aclkw->kw, ckw);
 					goto out_free_smp;
 				}
 			}
 
 			if (conv->in_type >= SMP_TYPES || conv->out_type >= SMP_TYPES) {
-				memprintf(err, "ACL keyword '%s' : returns type of conv method '%s' is unknown.",
+				memprintf(err, "ACL keyword '%s' : returns type of converter '%s' is unknown.",
 					  aclkw->kw, ckw);
 				goto out_free_smp;
 			}
 
 			/* If impossible type conversion */
 			if (!sample_casts[cur_type][conv->in_type]) {
-				memprintf(err, "ACL keyword '%s' : conv method '%s' cannot be applied.",
+				memprintf(err, "ACL keyword '%s' : converter '%s' cannot be applied.",
 					  aclkw->kw, ckw);
 				goto out_free_smp;
 			}
 
 			cur_type = conv->out_type;
-			conv_expr = calloc(1, sizeof(struct sample_conv_expr));
+			conv_expr = calloc(1, sizeof(*conv_expr));
 			if (!conv_expr)
 				goto out_free_smp;
 
@@ -313,7 +310,7 @@ struct acl_expr *parse_acl_expr(const char **args, char **err, struct arg_list *
 				int err_arg;
 
 				if (!conv->arg_mask) {
-					memprintf(err, "ACL keyword '%s' : conv method '%s' does not support any args.",
+					memprintf(err, "ACL keyword '%s' : converter '%s' does not support any args.",
 						  aclkw->kw, ckw);
 					goto out_free_smp;
 				}
@@ -321,7 +318,7 @@ struct acl_expr *parse_acl_expr(const char **args, char **err, struct arg_list *
 				al->kw = smp->fetch->kw;
 				al->conv = conv_expr->conv->kw;
 				if (make_arg_list(endw + 1, arg - endw - 1, conv->arg_mask, &conv_expr->arg_p, err, NULL, &err_arg, al) < 0) {
-					memprintf(err, "ACL keyword '%s' : invalid arg %d in conv method '%s' : %s.",
+					memprintf(err, "ACL keyword '%s' : invalid arg %d in converter '%s' : %s.",
 						  aclkw->kw, err_arg+1, ckw, *err);
 					goto out_free_smp;
 				}
@@ -330,19 +327,17 @@ struct acl_expr *parse_acl_expr(const char **args, char **err, struct arg_list *
 					conv_expr->arg_p = empty_arg_list;
 
 				if (conv->val_args && !conv->val_args(conv_expr->arg_p, conv, file, line, err)) {
-					memprintf(err, "ACL keyword '%s' : invalid args in conv method '%s' : %s.",
+					memprintf(err, "ACL keyword '%s' : invalid args in converter '%s' : %s.",
 						  aclkw->kw, ckw, *err);
 					goto out_free_smp;
 				}
 			}
 			else if (ARGM(conv->arg_mask)) {
-				memprintf(err, "ACL keyword '%s' : missing args for conv method '%s'.",
+				memprintf(err, "ACL keyword '%s' : missing args for converter '%s'.",
 					  aclkw->kw, ckw);
 				goto out_free_smp;
 			}
 		}
-		free(ckw);
-		ckw = NULL;
 	}
 	else {
 		/* This is not an ACL keyword, so we hope this is a sample fetch
@@ -358,10 +353,10 @@ struct acl_expr *parse_acl_expr(const char **args, char **err, struct arg_list *
 		cur_type = smp_expr_output_type(smp);
 	}
 
-	expr = (struct acl_expr *)calloc(1, sizeof(*expr));
+	expr = calloc(1, sizeof(*expr));
 	if (!expr) {
 		memprintf(err, "out of memory when parsing ACL expression");
-		goto out_free_smp;
+		goto out_return;
 	}
 
 	pattern_init_head(&expr->pat);
@@ -402,7 +397,6 @@ struct acl_expr *parse_acl_expr(const char **args, char **err, struct arg_list *
 			expr->pat.prune = pat_prune_fcts[PAT_MATCH_INT];
 			expr->pat.expect_type = pat_match_types[PAT_MATCH_INT];
 			break;
-		case SMP_T_ADDR:
 		case SMP_T_IPV4:
 		case SMP_T_IPV6:
 			expr->pat.parse = pat_parse_fcts[PAT_MATCH_IP];
@@ -444,7 +438,6 @@ struct acl_expr *parse_acl_expr(const char **args, char **err, struct arg_list *
 	 *   -u : force the unique id of the acl
 	 *   -- : everything after this is not an option
 	 */
-	refflags = PAT_REF_ACL;
 	patflags = 0;
 	is_loaded = 0;
 	unique_id = -1;
@@ -474,7 +467,7 @@ struct acl_expr *parse_acl_expr(const char **args, char **err, struct arg_list *
 				goto out_free_expr;
 			}
 
-			if (!pattern_read_from_file(&expr->pat, refflags, args[1], patflags, load_as_map, err, file, line))
+			if (!pattern_read_from_file(&expr->pat, PAT_REF_ACL, args[1], patflags, load_as_map, err, file, line))
 				goto out_free_expr;
 			is_loaded = 1;
 			args++;
@@ -507,7 +500,6 @@ struct acl_expr *parse_acl_expr(const char **args, char **err, struct arg_list *
 			args++;
 		}
 		else if (strcmp(*args, "-M") == 0) {
-			refflags |= PAT_REF_MAP;
 			load_as_map = 1;
 		}
 		else if (strcmp(*args, "--") == 0) {
@@ -539,10 +531,13 @@ struct acl_expr *parse_acl_expr(const char **args, char **err, struct arg_list *
 	}
 
 	/* Create new pattern expression associated to this reference. */
-	pattern_expr = pattern_new_expr(&expr->pat, ref, patflags, err, NULL);
+	pattern_expr = pattern_new_expr(&expr->pat, ref, err, NULL);
 	if (!pattern_expr)
 		goto out_free_expr;
 
+	/* Copy the pattern matching and indexing flags. */
+	pattern_expr->mflags = patflags;
+
 	/* now parse all patterns */
 	while (**args) {
 		arg = *args;
@@ -678,8 +673,8 @@ struct acl_expr *parse_acl_expr(const char **args, char **err, struct arg_list *
  out_free_expr:
 	prune_acl_expr(expr);
 	free(expr);
- out_free_smp:
 	free(ckw);
+ out_free_smp:
 	free(smp);
  out_return:
 	return NULL;
@@ -754,7 +749,7 @@ struct acl *parse_acl(const char **args, struct list *known_acl, char **err, str
 			memprintf(err, "out of memory when parsing ACL");
 			goto out_free_acl_expr;
 		}
-		cur_acl = (struct acl *)calloc(1, sizeof(*cur_acl));
+		cur_acl = calloc(1, sizeof(*cur_acl));
 		if (cur_acl == NULL) {
 			memprintf(err, "out of memory when parsing ACL");
 			goto out_free_name;
@@ -796,10 +791,12 @@ const struct {
 	{ .name = "HTTP_1.0",       .expr = {"req_ver","1.0",""}},
 	{ .name = "HTTP_1.1",       .expr = {"req_ver","1.1",""}},
 	{ .name = "METH_CONNECT",   .expr = {"method","CONNECT",""}},
+	{ .name = "METH_DELETE",    .expr = {"method","DELETE",""}},
 	{ .name = "METH_GET",       .expr = {"method","GET","HEAD",""}},
 	{ .name = "METH_HEAD",      .expr = {"method","HEAD",""}},
 	{ .name = "METH_OPTIONS",   .expr = {"method","OPTIONS",""}},
 	{ .name = "METH_POST",      .expr = {"method","POST",""}},
+	{ .name = "METH_PUT",       .expr = {"method","PUT",""}},
 	{ .name = "METH_TRACE",     .expr = {"method","TRACE",""}},
 	{ .name = "HTTP_URL_ABS",   .expr = {"url_reg","^[^/:]*://",""}},
 	{ .name = "HTTP_URL_SLASH", .expr = {"url_beg","/",""}},
@@ -851,7 +848,7 @@ static struct acl *find_acl_default(const char *acl_name, struct list *known_acl
 		goto out_free_acl_expr;
 	}
 
-	cur_acl = (struct acl *)calloc(1, sizeof(*cur_acl));
+	cur_acl = calloc(1, sizeof(*cur_acl));
 	if (cur_acl == NULL) {
 		memprintf(err, "out of memory when building default ACL '%s'", acl_name);
 		goto out_free_name;
@@ -912,7 +909,7 @@ struct acl_cond *parse_acl_cond(const char **args, struct list *known_acl,
 	struct acl_cond *cond;
 	unsigned int suite_val;
 
-	cond = (struct acl_cond *)calloc(1, sizeof(*cond));
+	cond = calloc(1, sizeof(*cond));
 	if (cond == NULL) {
 		memprintf(err, "out of memory when parsing condition");
 		goto out_return;
@@ -1000,7 +997,7 @@ struct acl_cond *parse_acl_cond(const char **args, struct list *known_acl,
 			}
 		}
 
-		cur_term = (struct acl_term *)calloc(1, sizeof(*cur_term));
+		cur_term = calloc(1, sizeof(*cur_term));
 		if (cur_term == NULL) {
 			memprintf(err, "out of memory when parsing condition");
 			goto out_free_suite;
@@ -1022,7 +1019,7 @@ struct acl_cond *parse_acl_cond(const char **args, struct list *known_acl,
 		suite_val &= cur_acl->val;
 
 		if (!cur_suite) {
-			cur_suite = (struct acl_term_suite *)calloc(1, sizeof(*cur_suite));
+			cur_suite = calloc(1, sizeof(*cur_suite));
 			if (cur_suite == NULL) {
 				memprintf(err, "out of memory when parsing condition");
 				goto out_free_term;
