@@ -155,7 +155,7 @@ REGPRM1 static int _do_init(struct poller *p)
 		goto fail_fd;
 
 	/* we can have up to two events per fd (*/
-	kev = (struct kevent*)calloc(1, sizeof(struct kevent) * 2 * global.maxsock);
+	kev = calloc(1, sizeof(struct kevent) * 2 * global.maxsock);
 	if (kev == NULL)
 		goto fail_kev;
 		
@@ -208,6 +208,8 @@ REGPRM1 static int _do_test(struct poller *p)
  */
 REGPRM1 static int _do_fork(struct poller *p)
 {
+	if (kqueue_fd >= 0)
+		close(kqueue_fd);
 	kqueue_fd = kqueue();
 	if (kqueue_fd < 0)
 		return 0;
@@ -232,7 +234,6 @@ static void _do_register(void)
 
 	p->name = "kqueue";
 	p->pref = 300;
-	p->flags = 0;
 	p->private = NULL;
 
 	p->clo  = NULL;
